pub mod login;
pub mod game_actions;
pub mod map_actions;

use game_actions::SpawnToken;
use serde::{Deserialize, Serialize};

use crate::game::chat_message::ChatMessage;

#[derive(Serialize, Deserialize, Default, Debug)]
#[serde(rename_all = "snake_case")]
pub enum Request {
    #[default]
    Error,
    Login(login::LoginRequest),
    Message(ChatMessage),
    GetChatHistory { amount: usize, from: usize },
    GetLastMessages { amount: usize, },
    GetTokens,
    SpawnToken { x: i32, y: i32, img_path: String },
    MoveToken { token_id: usize, x: i32, y: i32 },
    Quit,
    Kick(String),
    Shutdown
}
#[derive(Serialize, Clone, Debug)]
#[serde(rename_all = "snake_case")]
pub enum Response {
    Error(RequestError),
    Login(login::LoginResult),
    Message(ChatMessage),
    GetChatHistory(Vec<ChatMessage>),
    MoveToken { token_id: usize, x: i32, y: i32 },
    SpawnToken(SpawnToken),
    Quit { id: String },
    Shutdown,

}

#[derive(Serialize, Debug, Clone)]
#[serde(rename_all = "snake_case")]
pub enum RequestError {
    InvalidRequest,
    AlreadyLoggedIn,
}